/**
 * This export is a variant of the quickjs WASM library:
 * ### [@jitl/quickjs-browser-debug-sync-singlefile](https://github.com/justjake/quickjs-emscripten/blob/main/doc/packages/@jitl/quickjs-browser-debug-sync-singlefile/README.md)
 *
 * ESModule for browsers or browser-like environments
 *
 * | Variable            |    Setting                     |    Description    |
 * | --                  | --                             | --                |
 * | releaseMode         | debug | Enables assertions and memory sanitizers. Try to run your tests against debug variants, in addition to your preferred production variant, to catch more bugs. |
 * | syncMode            | sync | The default, normal build. Note that both variants support regular async functions. |
 * | moduleSystem        | esm | This variant exports an ESModule, which is standardized for browsers and more modern browser-like environments. It cannot be imported from CommonJS without shenanigans. |
 * | emscriptenInclusion | singlefile | The WASM runtime is included directly in the JS file. Use if you run into issues with missing .wasm files when building or deploying your app. |
 *
 */
const variant = {
    type: "sync",
    importFFI: () => import("./ffi.js").then((mod) => mod.QuickJSFFI),
    importModuleLoader: () => import("./emscripten-module.js").then((mod) => mod.default),
};
export default variant;
//# sourceMappingURL=index.js.map